@@ -289,8 +289,8 @@ bool GDALGeoLocDatasetAccessors::LoadGeoloc(bool bIsRegularGrid)
             GDALRasterBand::FromHandle(m_psTransform->hBand_Y));
     }
 
-    return GDALGeoLoc<GDALGeoLocDatasetAccessors>::LoadGeolocFinish(
-        m_psTransform);
+    GDALGeoLoc<GDALGeoLocDatasetAccessors>::LoadGeolocFinish(m_psTransform);
+    return true;
 }
 
 /*! @endcond */
