@@ -28,7 +28,6 @@
 
 #include "sdts_al.h"
 
-
 /************************************************************************/
 /* ==================================================================== */
 /*                            SDTSRawLine                               */
@@ -42,11 +41,8 @@
 /*                            SDTSRawLine()                             */
 /************************************************************************/
 
-SDTSRawLine::SDTSRawLine() :
-    nVertices(0),
-    padfX(nullptr),
-    padfY(nullptr),
-    padfZ(nullptr)
+SDTSRawLine::SDTSRawLine()
+    : nVertices(0), padfX(nullptr), padfY(nullptr), padfZ(nullptr)
 {
     nAttributes = 0;
 }
@@ -58,7 +54,7 @@ SDTSRawLine::SDTSRawLine() :
 SDTSRawLine::~SDTSRawLine()
 
 {
-    CPLFree( padfX );
+    CPLFree(padfX);
 }
 
 /************************************************************************/
@@ -69,58 +65,58 @@ SDTSRawLine::~SDTSRawLine()
 /*      the work in this whole file.                                    */
 /************************************************************************/
 
-int SDTSRawLine::Read( SDTS_IREF * poIREF, DDFRecord * poRecord )
+int SDTSRawLine::Read(SDTS_IREF *poIREF, DDFRecord *poRecord)
 
 {
     // E.Rouault: Not sure if this test is really useful
-    if( poRecord->GetStringSubfield( "LINE", 0, "MODN", 0 ) == nullptr )
+    if (poRecord->GetStringSubfield("LINE", 0, "MODN", 0) == nullptr)
         return FALSE;
 
-/* ==================================================================== */
-/*      Loop over fields in this record, looking for those we           */
-/*      recognise, and need.  I don't use the getSubfield()             */
-/*      interface on the record in order to retain some slight bit      */
-/*      of efficiency.                                                  */
-/* ==================================================================== */
-    for( int iField = 0; iField < poRecord->GetFieldCount(); iField++ )
+    /* ==================================================================== */
+    /*      Loop over fields in this record, looking for those we           */
+    /*      recognise, and need.  I don't use the getSubfield()             */
+    /*      interface on the record in order to retain some slight bit      */
+    /*      of efficiency.                                                  */
+    /* ==================================================================== */
+    for (int iField = 0; iField < poRecord->GetFieldCount(); iField++)
     {
-        DDFField        *poField = poRecord->GetField( iField );
-        if( poField == nullptr )
+        DDFField *poField = poRecord->GetField(iField);
+        if (poField == nullptr)
             return FALSE;
-        DDFFieldDefn* poFieldDefn = poField->GetFieldDefn();
-        if( poFieldDefn == nullptr )
+        DDFFieldDefn *poFieldDefn = poField->GetFieldDefn();
+        if (poFieldDefn == nullptr)
             return FALSE;
 
         const char *pszFieldName = poFieldDefn->GetName();
 
-        if( EQUAL(pszFieldName,"LINE") )
-            oModId.Set( poField );
+        if (EQUAL(pszFieldName, "LINE"))
+            oModId.Set(poField);
 
-        else if( EQUAL(pszFieldName,"ATID") )
-            ApplyATID( poField );
+        else if (EQUAL(pszFieldName, "ATID"))
+            ApplyATID(poField);
 
-        else if( EQUAL(pszFieldName,"PIDL") )
-            oLeftPoly.Set( poField );
+        else if (EQUAL(pszFieldName, "PIDL"))
+            oLeftPoly.Set(poField);
 
-        else if( EQUAL(pszFieldName,"PIDR") )
-            oRightPoly.Set( poField );
+        else if (EQUAL(pszFieldName, "PIDR"))
+            oRightPoly.Set(poField);
 
-        else if( EQUAL(pszFieldName,"SNID") )
-            oStartNode.Set( poField );
+        else if (EQUAL(pszFieldName, "SNID"))
+            oStartNode.Set(poField);
 
-        else if( EQUAL(pszFieldName,"ENID") )
-            oEndNode.Set( poField );
+        else if (EQUAL(pszFieldName, "ENID"))
+            oEndNode.Set(poField);
 
-        else if( EQUAL(pszFieldName,"SADR") )
+        else if (EQUAL(pszFieldName, "SADR"))
         {
-            nVertices = poIREF->GetSADRCount( poField );
+            nVertices = poIREF->GetSADRCount(poField);
 
             padfX = reinterpret_cast<double *>(
-                CPLRealloc( padfX, sizeof(double) * nVertices*3 ) );
+                CPLRealloc(padfX, sizeof(double) * nVertices * 3));
             padfY = padfX + nVertices;
-            padfZ = padfX + 2*nVertices;
+            padfZ = padfX + 2 * nVertices;
 
-            if( !poIREF->GetSADR( poField, nVertices, padfX, padfY, padfZ ) )
+            if (!poIREF->GetSADR(poField, nVertices, padfX, padfY, padfZ))
             {
                 return FALSE;
             }
@@ -136,32 +132,31 @@ int SDTSRawLine::Read( SDTS_IREF * poIREF, DDFRecord * poRecord )
 /*      Write info about this object to a text file.                    */
 /************************************************************************/
 
-void SDTSRawLine::Dump( FILE * fp )
+void SDTSRawLine::Dump(FILE *fp)
 
 {
-    fprintf( fp, "SDTSRawLine\n" );
-    fprintf( fp, "  Module=%s, Record#=%d\n",
-             oModId.szModule, oModId.nRecord );
-    if( oLeftPoly.nRecord != -1 )
-        fprintf( fp, "  LeftPoly (Module=%s, Record=%d)\n",
-                 oLeftPoly.szModule, oLeftPoly.nRecord );
-    if( oRightPoly.nRecord != -1 )
-        fprintf( fp, "  RightPoly (Module=%s, Record=%d)\n",
-                 oRightPoly.szModule, oRightPoly.nRecord );
-    if( oStartNode.nRecord != -1 )
-        fprintf( fp, "  StartNode (Module=%s, Record=%d)\n",
-                 oStartNode.szModule, oStartNode.nRecord );
-    if( oEndNode.nRecord != -1 )
-        fprintf( fp, "  EndNode (Module=%s, Record=%d)\n",
-                 oEndNode.szModule, oEndNode.nRecord );
-    for( int i = 0; i < nAttributes; i++ )
-        fprintf( fp, "  Attribute (Module=%s, Record=%d)\n",
-                 paoATID[i].szModule, paoATID[i].nRecord );
+    fprintf(fp, "SDTSRawLine\n");
+    fprintf(fp, "  Module=%s, Record#=%d\n", oModId.szModule, oModId.nRecord);
+    if (oLeftPoly.nRecord != -1)
+        fprintf(fp, "  LeftPoly (Module=%s, Record=%d)\n", oLeftPoly.szModule,
+                oLeftPoly.nRecord);
+    if (oRightPoly.nRecord != -1)
+        fprintf(fp, "  RightPoly (Module=%s, Record=%d)\n", oRightPoly.szModule,
+                oRightPoly.nRecord);
+    if (oStartNode.nRecord != -1)
+        fprintf(fp, "  StartNode (Module=%s, Record=%d)\n", oStartNode.szModule,
+                oStartNode.nRecord);
+    if (oEndNode.nRecord != -1)
+        fprintf(fp, "  EndNode (Module=%s, Record=%d)\n", oEndNode.szModule,
+                oEndNode.nRecord);
+    for (int i = 0; i < nAttributes; i++)
+        fprintf(fp, "  Attribute (Module=%s, Record=%d)\n", paoATID[i].szModule,
+                paoATID[i].nRecord);
 
-    for( int i = 0; i < nVertices; i++ )
+    for (int i = 0; i < nVertices; i++)
     {
-        fprintf( fp, "  Vertex[%3d] = (%.2f,%.2f,%.2f)\n",
-                 i, padfX[i], padfY[i], padfZ[i] );
+        fprintf(fp, "  Vertex[%3d] = (%.2f,%.2f,%.2f)\n", i, padfX[i], padfY[i],
+                padfZ[i]);
     }
 }
 
@@ -177,9 +172,9 @@ void SDTSRawLine::Dump( FILE * fp )
 /*                           SDTSLineReader()                           */
 /************************************************************************/
 
-SDTSLineReader::SDTSLineReader( SDTS_IREF * poIREFIn ) :
-    poIREF(poIREFIn)
-{}
+SDTSLineReader::SDTSLineReader(SDTS_IREF *poIREFIn) : poIREF(poIREFIn)
+{
+}
 
 /************************************************************************/
 /*                             ~SDTSLineReader()                        */
@@ -207,10 +202,10 @@ void SDTSLineReader::Close()
 /*      data records.                                                   */
 /************************************************************************/
 
-int SDTSLineReader::Open( const char * pszFilename )
+int SDTSLineReader::Open(const char *pszFilename)
 
 {
-    return oDDFModule.Open( pszFilename );
+    return oDDFModule.Open(pszFilename);
 }
 
 /************************************************************************/
@@ -222,26 +217,26 @@ int SDTSLineReader::Open( const char * pszFilename )
 SDTSRawLine *SDTSLineReader::GetNextLine()
 
 {
-/* -------------------------------------------------------------------- */
-/*      Are we initialized?                                             */
-/* -------------------------------------------------------------------- */
-    if( oDDFModule.GetFP() == nullptr )
+    /* -------------------------------------------------------------------- */
+    /*      Are we initialized?                                             */
+    /* -------------------------------------------------------------------- */
+    if (oDDFModule.GetFP() == nullptr)
         return nullptr;
 
-/* -------------------------------------------------------------------- */
-/*      Read the record.                                                */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Read the record.                                                */
+    /* -------------------------------------------------------------------- */
     DDFRecord *poRecord = oDDFModule.ReadRecord();
 
-    if( poRecord == nullptr )
+    if (poRecord == nullptr)
         return nullptr;
 
-/* -------------------------------------------------------------------- */
-/*      Transform into a line feature.                                  */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      Transform into a line feature.                                  */
+    /* -------------------------------------------------------------------- */
     SDTSRawLine *poRawLine = new SDTSRawLine();
 
-    if( poRawLine->Read( poIREF, poRecord ) )
+    if (poRawLine->Read(poIREF, poRecord))
     {
         return poRawLine;
     }
@@ -270,48 +265,49 @@ SDTSRawLine *SDTSLineReader::GetNextLine()
 
 */
 
-void SDTSLineReader::AttachToPolygons( SDTSTransfer * poTransfer,
-                                       int iTargetPolyLayer )
+void SDTSLineReader::AttachToPolygons(SDTSTransfer *poTransfer,
+                                      int iTargetPolyLayer)
 
 {
-    if( !IsIndexed() )
-        return;
-
-/* -------------------------------------------------------------------- */
-/*      We force a filling of the index because when we attach the      */
-/*      lines we are just providing a pointer back to the line          */
-/*      features in this readers index.  If they aren't cached in       */
-/*      the index then the pointer will be invalid.                     */
-/* -------------------------------------------------------------------- */
+    /* -------------------------------------------------------------------- */
+    /*      We force a filling of the index because when we attach the      */
+    /*      lines we are just providing a pointer back to the line          */
+    /*      features in this readers index.  If they aren't cached in       */
+    /*      the index then the pointer will be invalid.                     */
+    /* -------------------------------------------------------------------- */
     FillIndex();
 
-/* ==================================================================== */
-/*      Loop over all lines, attaching them to the polygons they        */
-/*      have as right and left faces.                                   */
-/* ==================================================================== */
+    /* ==================================================================== */
+    /*      Loop over all lines, attaching them to the polygons they        */
+    /*      have as right and left faces.                                   */
+    /* ==================================================================== */
     Rewind();
     SDTSRawLine *poLine = nullptr;
     SDTSPolygonReader *poPolyReader = nullptr;
-    while( (poLine = reinterpret_cast<SDTSRawLine *>( GetNextFeature()) )
-           != nullptr )
+    while ((poLine = reinterpret_cast<SDTSRawLine *>(GetNextFeature())) !=
+           nullptr)
     {
-/* -------------------------------------------------------------------- */
-/*      Skip lines with the same left and right polygon face.  These    */
-/*      are dangles, and will not contribute in any useful fashion      */
-/*      to the resulting polygon.                                       */
-/* -------------------------------------------------------------------- */
-        if( poLine->oLeftPoly.nRecord == poLine->oRightPoly.nRecord )
+        /* --------------------------------------------------------------------
+         */
+        /*      Skip lines with the same left and right polygon face.  These */
+        /*      are dangles, and will not contribute in any useful fashion */
+        /*      to the resulting polygon. */
+        /* --------------------------------------------------------------------
+         */
+        if (poLine->oLeftPoly.nRecord == poLine->oRightPoly.nRecord)
             continue;
 
-/* -------------------------------------------------------------------- */
-/*      If we don't have our indexed polygon reader yet, try to get     */
-/*      it now.                                                         */
-/* -------------------------------------------------------------------- */
-        if( poPolyReader == nullptr )
+        /* --------------------------------------------------------------------
+         */
+        /*      If we don't have our indexed polygon reader yet, try to get */
+        /*      it now. */
+        /* --------------------------------------------------------------------
+         */
+        if (poPolyReader == nullptr)
         {
-            int         iPolyLayer;
+            int iPolyLayer;
 
-            if( poLine->oLeftPoly.nRecord != -1 )
+            if (poLine->oLeftPoly.nRecord != -1)
             {
                 iPolyLayer = poTransfer->FindLayer(poLine->oLeftPoly.szModule);
             }
@@ -320,38 +316,39 @@ void SDTSLineReader::AttachToPolygons( SDTSTransfer * poTransfer,
                 iPolyLayer = poTransfer->FindLayer(poLine->oRightPoly.szModule);
             }
 
-            if( iPolyLayer == -1 )
+            if (iPolyLayer == -1)
                 continue;
 
-            if( iPolyLayer != iTargetPolyLayer )
+            if (iPolyLayer != iTargetPolyLayer)
                 continue;
 
             poPolyReader = reinterpret_cast<SDTSPolygonReader *>(
-                poTransfer->GetLayerIndexedReader(iPolyLayer) );
+                poTransfer->GetLayerIndexedReader(iPolyLayer));
 
-            if( poPolyReader == nullptr )
+            if (poPolyReader == nullptr)
                 return;
         }
 
-/* -------------------------------------------------------------------- */
-/*      Attach line to right and/or left polygons.                      */
-/* -------------------------------------------------------------------- */
-        if( poLine->oLeftPoly.nRecord != -1 )
-        {
-          SDTSRawPolygon *poPoly = reinterpret_cast<SDTSRawPolygon *>(
-              poPolyReader->GetIndexedFeatureRef( poLine->oLeftPoly.nRecord ) );
-            if( poPoly != nullptr )
-                poPoly->AddEdge( poLine );
-        }
-
-        if( poLine->oRightPoly.nRecord != -1 )
+        /* --------------------------------------------------------------------
+         */
+        /*      Attach line to right and/or left polygons. */
+        /* --------------------------------------------------------------------
+         */
+        if (poLine->oLeftPoly.nRecord != -1)
         {
             SDTSRawPolygon *poPoly = reinterpret_cast<SDTSRawPolygon *>(
-                poPolyReader->GetIndexedFeatureRef(
-                    poLine->oRightPoly.nRecord ) );
+                poPolyReader->GetIndexedFeatureRef(poLine->oLeftPoly.nRecord));
+            if (poPoly != nullptr)
+                poPoly->AddEdge(poLine);
+        }
 
-            if( poPoly != nullptr )
-                poPoly->AddEdge( poLine );
+        if (poLine->oRightPoly.nRecord != -1)
+        {
+            SDTSRawPolygon *poPoly = reinterpret_cast<SDTSRawPolygon *>(
+                poPolyReader->GetIndexedFeatureRef(poLine->oRightPoly.nRecord));
+
+            if (poPoly != nullptr)
+                poPoly->AddEdge(poLine);
         }
     }
 }
